# mkdocs-twincat-doc-plugin
MkDocs plugin to import retrieve docstrings from TwinCAT project objects and add to docs.



# Developing mkdocs-twincat-doc-plugin

To install mkdocs-twincat-doc-plugin, along with the tools you
need to develop and run tests, run the following in your virtualenv:

```bash
$ pip install -e . [dev]
```